% Deterministic steady state equilibrium equations

function D = dyn_det(X)

% Model parameters
  global M_
  
  par = cell2struct(...
        num2cell(M_.params),...
        cellstr(M_.param_names)...
        );

  muH  = par.muH;
  muF  = par.muF;
  FH   = par.FH;
  FF   = par.FF;
  lam  = par.lam;

  nH = min(1,max(0,X(1)));
  nF = min(1,max(0,X(2)));
  wH = max(0,X(5));
  wF = max(0,X(6));

  [cH YH WH qH pH dH mH yH lHy lHq IH UcH kH RH ...
   cF YF WF qF pF dF mF yF lFy lFq IF UcF kF RF] = sseqs(X); %#ok<NASGU,ASGLU>

% Labor market clearing:
  d1 = nH - IH*(lHy + lHq);
  d2 = nF - IF*(lFy + lFq);

% Capital market clearing:
  d3 = kH - IH*FH;
  d4 = kF - IF*FF;

% FOC for labor:
  if lam > 0;
    % GHH preferences
    d5 = wH - lam*muH*nH^(muH-1);
    d6 = wF - lam*muF*nF^(muF-1);
  else
    % Standard preferences
    d5 = wH - (1 - muH)/muH*cH/(1 - nH);
    d6 = wF - (1 - muF)/muF*cF/(1 - nF);
  end

  D = [d1 d2 d3 d4 d5 d6]';
    
end