// -----------------------------------------------
// Dynare .mod file to solve:
// IRBC model with two countries (H,F) and quality
// by Diego Gruber
// BEFORE RUNNING THE CODE: READ notes just below "model;"
// -----------------------------------------------

oo_.steady_state=zeros(85,1);
load('dyn_main_M.mat')

@#define countries = [ "H", "F" ]

// DECLARE MODEL PARAMETERS 

parameters 
  bet     // Discounting parameter
  gam     // Returns to quality
  nu      // Elasticity of substitution
  muH     // Elasticity of labor supply
  muF     // Elasticity of labor supply
  the     // Utility modifier
  FH      // Fixed cost of intermediate firms in units of capital
  FF      // Fixed cost of intermediate firms in units of capital
  tau     // Iceberg transportation costs
  phib    // Saving costs parameter
  phik    // Capital adjustment cost parameter
  eta     // Capital adjustment cost parameter
  del     // Capital depreciation rate
  alfH    // Home bias parameter at Home
  alfF    // Home bias parameter at Foreign
  lam     // GHH parameter
  rho     // Cost of q modifier
  aHH     // Shock-process parameters
  aHF
  aFH
  aFF


  ;


// DECLARE EXOGENOUS VARIABLES

varexo  eH eF;

// DECLARE ENDOGENOUS VARIABLES

var r        // World interest rate


  @#for co in countries

    c@{co}   // Consumption
    Y@{co}   // Output of final good
    W@{co}   // "Effective" world income
    q@{co}   // Quality
    p@{co}   // Prices
    d@{co}   // Domestic demand
    m@{co}   // Foreign demand
    y@{co}   // Output of intermediate good
    l@{co}y  // Manufacturing labor demand
    l@{co}q  // q-enhancing labor demand
    I@{co}   // Number of firms
    Uc@{co}  // Marginal utility of consumption
    n@{co}   // Labor supply
    x@{co}   // Investment
    k@{co}   // Capital
    R@{co}   // Rental price of capital
    b@{co}   // Savings
    w@{co}   // Salaries
    z@{co}   // Technology shocks to manufacturing

    mY@{co}  // Measured Y
    mc@{co}  // Measured c
    mx@{co}  // Measured x
    tot@{co} // Terms of trade
    P@{co}   // Price index
    rer@{co} // Real exchange rate
    ex@{co}  // Exports
    gdp@{co} // GDP
    nx@{co}  // Net exports
    RY@{co}  // Relative output
    RC@{co}  // Relative consumption

    qadj@{co} // Quality adjustment to prices
    qY@{co}   // Quality adjusted Y
    qc@{co}   // Quality adjusted c
    qx@{co}   // Quality adjusted x
    qtot@{co} // Quality adjusted Terms of trade
    qP@{co}   // Quality adjusted Price index
    qrer@{co} // Quality adjusted Real exchange rate
    qex@{co}  // Quality adjusted Exports
    qgdp@{co} // Quality adjusted GDP
    qnx@{co}  // Quality adjusted Net exports
    qRY@{co}  // Quality adjusted Relative output
    qRC@{co}  // Quality adjusted Relative consumption

    
  @#endfor
  ;

// DECLARE EXTERNAL FUNCTIONS

external_function(name = psi,   nargs = 2);
external_function(name = psix,  nargs = 2);
external_function(name = psinv, nargs = 1);
external_function(name = pss,   nargs = 1);
external_function(name = qss,   nargs = 1);
external_function(name = Rss,   nargs = 1);

// CALIBRATION

// Choose case (Default, GHH, Recent)

// @#define case = "Default"
// @#define case = "Heathcoate-Perri"
// @#define case = "Recent"
 @#define case = "GHH"

// Default case
  
bet  = 0.99;  // match r
the  = -1;    // from literature 
phib = 0.01;  // from literature
lam  = 0;     // default (no GHH) 
gam  = 1;     // fixed
tau  = 1;     // fixed  
phik = 1;     // fixed 
muH  = 0.37;  // match n  
muF  = muH;   // "    
FH   = .02;//0.2;   // match corr(gdpH,xH) 
FF   = FH;    // "
del  = .025; //0.033; // match x/k  
nu   = .73; //.665;  // match x   
eta  = .96; //0.92;  // match sd(x)/sd(gdp) 
alfH = .64;  // match m/gdp  
alfF = alfH;  // "    
rho  = 0.96;  // 
aHH  = 0.84;  // match corr(cH,cF)
aFF  = aHH;   // "
aFH  = 0.100; // match corr(nH,nF)
aHF  = aFH;   // " 

psF = 1; //VALUE MUST BE CORRECTED
qsF = 1;
RsF = 1;
psH = psF;
qsH = qsF;
RsH = RsF;


shocks;
  var  eH; stderr 0.025; //0.012; // match sd(gdpH)
  var  eF; stderr 0.025; //0.012; // "
  corr eH,eF = 0.42;     // match corr(gdpH,gdpF)      
end;

@#if case == "Heathcoate-Perri"

  del  = 0.03;  // match x/k  
  nu   = 0.665; // match x  
  eta  = 0.95;  // match sd(x)/sd(gdp) 
  alfH = 0.64;  // match m/gdp  
  alfF = alfH;  // "    
  rho  = 0.96;  // 

  aHH  = 0.97;  // 
  aFF  = aHH;   // 
  aFH  = 0.025; // 
  aHF  = aFH;   //  

  shocks;
    var  eH; stderr 0.0073; // match sd(gdpH)
    var  eF; stderr 0.0073; // "
    corr eH,eF = 0.290;     // match corr(gdpH,gdpF)      
  end;

@#endif

@#if case == "GHH"
    
  muH  = 3;   
  muF  = muH; 
  lam  = 4.7;   
  del  = 0.03;
  eta  = 0.955;

shocks;
  var  eH; stderr 0.025;//0.012; // match sd(gdpH)
  var  eF; stderr 0.025;//0.0125; // "
  corr eH,eF = 0.42;//0.4;     // match corr(gdpH,gdpF)      
end;

@#endif

@#if case == "Recent"

  alfH = .623;  // match m/gdp  
  alfF = alfH;
  del = 0.028;
  eta  = 0.97;

  shocks;
  var  eH; stderr 0.008; // match sd(gdpH)
  var  eF; stderr 0.008; // "
  corr eH,eF = 0.84;     // match corr(gdpH,gdpF)    
  
end;

@#endif

// MODEL EQUATIONS

model;
//ATENTION ATENTION ATENTION ATENTION ATENTION
//1) Run the code with next 6 rows included and the following 6 written rows commented.
//2) Take the computed steady state values from oo_ for each of these following 6 variables.
//3) Comment the next 6 rows and use the following 6 written with the correct steady state values.

 /* # psH = pss(1);
  # psF = pss(2);
  # qsH = qss(1);
  # qsF = qss(2);
  # RsH = Rss(1);
  # RsF = Rss(2); */

#psH=0.001342274;
#psF=0.001342274;
#qsH=0.000857812;
#qsF=0.000857812;
#RsH=1;
#RsF=1;
  
  @#for co in countries

  @# if co == countries[1]
  @#  define oc = countries[2]
  @# else
  @#  define oc = countries[1]
  @# endif

  // Household's budget constraint (c)
     c@{co} = w@{co}*n@{co} + R@{co}*k@{co}(-1) + b@{co}(-1) - phib/2*b@{co}(-1)^2 - x@{co} - r*b@{co};

  // Domestic absorption (Y)
     Y@{co} = c@{co} + x@{co};

  // Adjusted world income (W)
     W@{co} = (alf@{co}^(1/(1-nu))*Y@{co} + (1-alf@{oc})^(1/(1-nu))*tau^(-nu/(1 - nu))*Y@{oc});

  // Intermediate good quality (q)
     q@{co} = ((gam - rho)*z@{co}^(nu/(1 - nu))*W@{co}*(nu/w@{co})^(1/(1 - nu)))^((1 - nu)/(1 - (gam - rho + 1)*nu));
    // different in version 5 : q@{co} = ((gam - rho)*z@{co}^(nu/(1 - nu))*W@{co}*(nu/w@{co})^(1/(1 - nu)))^((1 - nu)/(2-rho - (gam - rho + 1)*nu));//in V5

  // Intermediate good price (p)
     p@{co} = (1/nu)*q@{co}^rho*w@{co}/z@{co};
    // different in version 5 : p@{co} = (1/nu)*q@{co}*w@{co}/z@{co}; //in V5

  // Domestic intermediates demand (d)
     d@{co} = Y@{co}*(alf@{co}*q@{co}^(gam*nu)/p@{co})^(1/(1 - nu));

  // Foreign intermediates demand (m)
     m@{co} = Y@{co}*((1-alf@{co})*q@{oc}^(gam*nu)/(tau*p@{oc}))^(1/(1 - nu));

  // Intermediate goods production (y)
     y@{co} = d@{co} + tau*m@{oc};

  // Manufacturing labor demand (ly)
     l@{co}y = y@{co}*q@{co}^rho/z@{co};
    // different in version 5 : l@{co}y = y@{co}*q@{co}/z@{co};//in V5

  // Quality labor demand (lq)
     l@{co}q = q@{co};
    // different in version 5 :l@{co}q = q@{co}/z@{co}; //in V5

  // Number of firms from Income Accounts identity (I)
     I@{co} = (n@{co}*w@{co}+k@{co}(-1)*R@{co})/(y@{co}*p@{co});

  @#if case=="GHH"

    // Marginal utilities with GHH preferences (Uc)
       Uc@{co} = (c@{co} - lam*n@{co}^mu@{co})^(the-1);

    // FOC for labor (n)
       w@{co} = lam*mu@{co}*n@{co}^(mu@{co}-1);

  @#else

    // Marginal utilities with standard preferences
       Uc@{co} = mu@{co}*c@{co}^(the*mu@{co} - 1)*(1 - n@{co})^(the*(1 - mu@{co}));
        // different in version 5 : Uc@{co} = c@{co}^(the*mu@{co} - 1)*(1 - n@{co})^(the*(1 - mu@{co})); //in V5

    // FOC for labor (n)
       w@{co} = (1 - mu@{co})/mu@{co}*c@{co}/(1 - n@{co}); 
     
  @#endif

  // Capital formation with adjustment costs (k)
     k@{co} = (1-del)*k@{co}(-1) + psi(x@{co},k@{co}(-1))*k@{co}(-1);

  // Derivative of x_t wrt K_t
     # dxdk0@{co} = 1/eta*(x@{co}/k@{co}(-1))^(1-eta);

  // Derivative of x_t+1 wrt K_t
     # dxdk1@{co} = -1/eta*(x@{co}(+1)/k@{co})^(1-eta)*k@{co}(+1)/k@{co} + x@{co}(+1)/k@{co};

  // Euler equation for investment (x)
     //Uc@{co} = bet*Uc@{co}(+1)*eta*phik*(k@{co}(-1)/x@{co})^(1-eta)*(R@{co}(+1) + x@{co}(+1)^(1-eta)/(eta*phik)*k@{co}(+1)/k@{co}^(2-eta) - x@{co}(+1)/k@{co});
     Uc@{co}*dxdk0@{co} = bet*Uc@{co}(+1)*(R@{co}(+1) - dxdk1@{co});

  // Euler equation for bond holdings (b)
     Uc@{co} = bet*Uc@{co}(+1)*(1-phib*b@{co})/r;

  // Labor market clearing (w)
     n@{co} = I@{co}*(l@{co}y + l@{co}q);

  // Capital market clearing (R)
     k@{co}(-1) = I@{co}*F@{co};

  // Shock processes (z)
     z@{co} = exp(a@{co}@{co}*log(z@{co}(-1)) + a@{co}@{oc}*log(z@{oc}(-1)) + e@{co});

  // NATIONAL ACCOUNTING

  // Real GDP (gdp)
     gdp@{co} = I@{co}*ps@{co}*(d@{co}+tau*m@{oc});

  // Exports (ex)
     ex@{co} = tau*I@{co}*m@{oc}*ps@{co};

  // Measured absorption
     mY@{co} = gdp@{co} - (ex@{co} - ex@{oc});

  // Measured investment
     mx@{co} = x@{co}*mY@{co}/Y@{co};

  // Measured consumption
     mc@{co} = c@{co}*mY@{co}/Y@{co};

  // Terms of trade (tot)
     tot@{co} = (p@{oc}/p@{co})*(ps@{co}/ps@{oc});

  // Price index (P)
     # M@{co} = ex@{oc}/mY@{co};
     P@{co} = (1-M@{co})*p@{co}/ps@{co} + M@{co}*p@{oc}/ps@{oc};

  // Real exchange rate (rer)
     rer@{co} = P@{oc}/P@{co};

  // Net exports (nx)
     nx@{co} = (ex@{co}-ex@{oc})/gdp@{co};
    
  // Relative output (RY)
     RY@{co} = gdp@{co}/gdp@{oc};
    
  // Relative consumption (RC)
     RC@{co} = mc@{co}/mc@{oc};

  // NATIONAL ACCOUNTING WITH QUALITY ADJUSTMENT

  // Quality adjustment factor:
     qadj@{co} = (q@{co}/qs@{co})^rho;

  // Real GDP (gdp)
     qgdp@{co} = gdp@{co}*qadj@{co};

  // Exports (ex)
     qex@{co} = ex@{co}*qadj@{co};

  // Measured absorption
     qY@{co} = qgdp@{co} - (qex@{co} - qex@{oc});

  // Measured investment
     qx@{co} = x@{co}*qY@{co}/Y@{co};

  // Measured consumption
     qc@{co} = c@{co}*qY@{co}/Y@{co};

  // Terms of trade (tot)
     qtot@{co} = tot@{co}*(qadj@{co}/qadj@{oc});

  // Price index (P)
     # Mq@{co} = qex@{oc}/qY@{co};
     qP@{co} = (1-Mq@{co})*p@{co}/(ps@{co}*qadj@{co}) + Mq@{co}*p@{oc}/(ps@{oc}*qadj@{oc});

  // Real exchange rate (rer)
     qrer@{co} = qP@{oc}/qP@{co};

  // Net exports (nx)
     qnx@{co} = (qex@{co}-qex@{oc})/qgdp@{co};
    
  // Relative output (RY)
     qRY@{co} = qgdp@{co}/qgdp@{oc};
      
  // Relative consumption (RC)
     qRC@{co} = qc@{co}/qc@{oc};

  @#endfor

  // Debt market clearing (r)
     bH = -bF;

end;

// STEADY STATE

steady(maxit=1000);

  

// SOLVE MODEL

// check;

// Plot IRFs for selected variables
//stoch_simul(order=1,nomoments,nocorr,noprint,nograph,irf=50)  gdpH mH nxH qH qF wH pH pF totH PH cH PF cF rerH RCH;
stoch_simul(order=1,nomoments,nocorr,noprint,nograph,irf=50)  gdpH qgdpH nxH qnxH qH totH qtotH PH qPH cH qcH rerH qrerH RCH qRCH;
Nsim = 10;
oo_sim = zeros(Nsim,M_.endo_nbr,200);

for i=1:Nsim

  set_dynare_seed(i);

  stoch_simul(
    order=1
    //,hp_filter=1600
    ,nomoments
    ,nocorr
    ,nograph
    ,noprint
    ,irf=0
    ,periods=200
    );

  oo_sim(i,:,:) = oo_.endo_simul;

end;

//AFTER RUNNING THIS FILE (if any error appears), WRITE IN THE COMMAND WINDOW "model_diagnostics(M_,options_,oo_)" to check for collinearity and other problems

