
function [newss, ssH, ssF, stdH, stdF, acrH, acrF, corH, corF, corHF] = dyn_stats_qadj(M_,oo_,oo_sim)

  %global newss

  % Run dynare 
  %dyn_main;
 
  % STEADY STATE PROPERTIES
  
  %SS = dyn_main_steadystate();
  SS = dyn_sssim('ss',M_,oo_);
  
  % Domestic
  ssH = struct(...
    'n',  SS.nH,...
    'c',  SS.qcH/SS.qgdpH,...
    'x',  SS.qxH/SS.qgdpH,...
    'm',  SS.qexF/SS.qgdpH,...
    'xk', SS.xH/SS.kH...
    ); 
  
  
  % Foreign
  ssF = struct(...
    'n',  SS.nF,...
    'c',  SS.qcF/SS.qgdpF,...
    'x',  SS.qxF/SS.qgdpF,...
    'm',  SS.qexH/SS.qgdpF,...
    'xk', SS.xF/SS.kF...
    ); 
  
  % SIMULATED STATISTICS
  
  Nsim = size(oo_sim,1);  
  
  % Initialize matrices
  stdH  = zeros(Nsim,7);
  stdF  = zeros(Nsim,7);
  acrH  = zeros(Nsim,6);
  acrF  = zeros(Nsim,6);
  corH  = zeros(Nsim,7);
  corF  = zeros(Nsim,7);
  corHF = zeros(Nsim,6);

  for i=1:Nsim;

    S = dyn_sssim('simul',M_,oo_sim(i,:,:));

    % Domestic standard deviations
    stdH(i,:) = [
     std(S.qgdpH).^2
     std(S.nH)  
     std(S.qcH)   
     std(S.qxH)  
     std(S.qnxH) 
     std(S.qtotH)
     std(S.qYH)  
     ]./std(S.qgdpH)';
     
    % Foreign 
    stdF(i,:) = [
     std(S.qgdpF).^2
     std(S.nF)  
     std(S.qcF)   
     std(S.qxF)   
     std(S.qnxF)  
     std(S.qtotF)
     std(S.qYF)  
     ]./std(S.qgdpF)';
 
    % Domestic autocorrelations
    temp = [
      autocorr(S.qgdpH,1)'
      autocorr(S.nH,1)'
      autocorr(S.qcH,1)'
      autocorr(S.qxH,1)'
      autocorr(S.qnxH,1)'
      autocorr(S.qtotH,1)'
      ];
    acrH(i,:) = temp(:,2)';
    
    % Foreign
    temp = [
      autocorr(S.qgdpF,1)'
      autocorr(S.nF,1)'
      autocorr(S.qcF,1)'
      autocorr(S.qxF,1)'
      autocorr(S.qnxF,1)'
      autocorr(S.qtotF,1)'
      ];
    acrF(i,:) = temp(:,2)';

    % Domestic correlations between variables
    corH(i,:) = [
     corr(S.qgdpH,S.nH) 
     corr(S.qgdpH,S.qcH)
     corr(S.qgdpH,S.qxH)
     corr(S.qgdpH,S.qnxH)
     corr(S.qgdpH,S.qtotH)
     corr(S.qcH,S.nH)
     corr(S.qcH,S.qxH)
     ]';
     
   % Foreign
   corF(i,:) = [
     corr(S.qgdpH,S.nH) 
     corr(S.qgdpH,S.qcH)
     corr(S.qgdpH,S.qxH)
     corr(S.qgdpH,S.qnxH)
     corr(S.qgdpH,S.qtotH)
     corr(S.qcH,S.nH)
     corr(S.qcH,S.qxH)
     ]';
   
   % Cross-country
   corHF(i,:) = [
     corr(S.qgdpH,S.qgdpF)
     corr(S.nH,S.nF)
     corr(S.qcH,S.qcF)
     corr(S.qxH,S.qxF)
     corr(S.qRCF,S.qrerF)
     corr(S.qRYF,S.qrerF)
     ]';

  end
  
  % Labels
  labsd = {'gdp','n','c','x','nx','tt','Y'};
  labac = {'gdp','n','c','x','nx','tt'};
  labcr = {'yn','yc','yx','ynx','ytt','cn','cx'};
  labic = {'yy','nn','cc','xx','rcrer','ryrer'};
  
  % Average over all simulations and create structured output
  makestr = @(X,L) cell2struct(num2cell(mean(X)'),L);
  stdH  = makestr(stdH,labsd);
  stdF  = makestr(stdF,labsd);
  acrH  = makestr(acrH,labac);
  acrF  = makestr(acrF,labac);
  corH  = makestr(corH,labcr);
  corF  = makestr(corF,labcr);
  corHF = makestr(corHF,labic);
  
  % Check convergence to calibration target
%   out = [
%     ssH.n - goal(1)
%     ssH.x - goal(2)  
%     ssH.m - goal(3)
%     ];
  
  
  % Update steady state
  myceil = @(x,y) ceil(x/y)*y;
  newss = [SS.nH SS.nF SS.xH SS.xF SS.wH SS.wF]';
  newss = myceil(newss,0.01);
  
  %fprintf('New parameters : %.2f \n', par');
  %fprintf('Distance to target   : %g \n',norm(out,Inf));
  
end 