function [cH YH WH qH pH dH mH yH lHy lHq IH UcH kH RH ...
          cF YF WF qF pF dF mF yF lFy lFq IF UcF kF RF] = sseqs(X)
        
% Model parameters
  global M_
  
  par = cell2struct(...
        num2cell(M_.params),...
        cellstr(M_.param_names)...
        );
  
  bet   = par.bet;
  muH   = par.muH;
  muF   = par.muF;
  lam   = par.lam;
  the   = par.the;
  nu    = par.nu;   
  alfH  = par.alfH;  
  alfF  = par.alfF;  
  gam   = par.gam;  
  del   = par.del; 
  eta   = par.eta;
  phik  = par.phik;
  tau   = par.tau;
  rho   = par.rho;

  nH  = min(1,max(0,X(1)));
  nF  = min(1,max(0,X(2)));
  xH  = max(0,X(3));
  xF  = max(0,X(4));
  wH  = max(0,X(5));
  wF  = max(0,X(6));

% Steady state capital (k)
  kH = xH/psinv(del);
  kF = xF/psinv(del);

% Steady state rental price (R)
  RH = (del/phik)^(1/eta)*(1/(eta*del)*(1/bet-1) + 1);
  RF = (del/phik)^(1/eta)*(1/(eta*del)*(1/bet-1) + 1);

% Household's budget constraint (c)
  cH = wH*nH + RH*kH - xH;
  cF = wF*nF + RF*kF - xF;

% Feasibility (Y)
  YH = cH + xH;
  YF = cF + xF;

% Adjusted world income
  WH = (alfH^(1/(1-nu))*YH + (1-alfF)^(1/(1-nu))*tau^(-nu/(1 - nu))*YF);
  WF = (alfF^(1/(1-nu))*YF + (1-alfH)^(1/(1-nu))*tau^(-nu/(1 - nu))*YH);

% Intermediate good quality (q)
  qH = ((gam - rho)*WH*(nu/wH)^(1/(1 - nu)))^((1 - nu)/(1 - (gam - rho + 1)*nu));
  qF = ((gam - rho)*WF*(nu/wF)^(1/(1 - nu)))^((1 - nu)/(1 - (gam - rho + 1)*nu));

% Intermediate good price (p)
  pH = (1/nu)*qH^rho*wH;
  pF = (1/nu)*qF^rho*wF;

% Domestic intermediates demand (x)
  dH = YH*(alfH*qH^(gam*nu)/pH)^(1/(1 - nu));
  dF = YF*(alfF*qF^(gam*nu)/pF)^(1/(1 - nu));

% Foreign intermediates demand (m)
  mH = YH*((1-alfH)*qF^(gam*nu)/(tau*pF))^(1/(1 - nu));
  mF = YF*((1-alfF)*qH^(gam*nu)/(tau*pH))^(1/(1 - nu));

% Intermediate goods production (y)
  yH = dH + tau*mF;
  yF = dF + tau*mH;

% Manufacturing labor demand (ly)
  lHy = yH*qH^rho;
  lFy = yF*qF^rho;

% Quality labor demand (lq)
  lHq = qH;
  lFq = qF;

% Number of firms (I)
  IH = (nH*wH+kH*RH)/(yH*pH);
  IF = (nF*wF+kF*RF)/(yF*pF);
  
% Marginal utilities
  if lam > 0;
  % GHH preferences
    UcH = (cH - lam*nH^muH)^(the-1);
    UcF = (cF - lam*nF^muF)^(the-1);
  else
  % Standard preferences
    UcH = muH*cH^(the*muH - 1)*(1 - nH)^(the*(1 - muH));
    UcF = muF*cF^(the*muF - 1)*(1 - nF)^(the*(1 - muF));
  end
  
end        