% Deterministic steady state equilibrium equations

function D = sym_det(X)

% Model parameters
  global par

  mu  = par.mu;
  F   = par.F;
  lam = par.lam;

  n = X(1);
  k = X(2);
  w = X(3);

  [c , ~, ~, ~, ~, ~, ~, ~, ly, lq, I] = sym_sseqs(X); 

% Labor market clearing:
  d1 = n - I*(ly + lq);

% Capital market clearing:
  d2 = k - I*F;

% FOC for labor:
  if lam == 0
    d3 = w - (1 - mu)/mu*c/(1 - n);
  else
    d3 = w - lam*mu*n^(mu - 1);
  end

  D = [d1 d2 d3]';
    
end