function [c Y W q p d m y ly lq I Uc x R] = sym_sseqs(X)
        
% Model parameters
  global par
  
  bet   = par.bet;
  mu    = par.mu;
  the   = par.the;
  nu    = par.nu;   
  alf   = par.alf;
  gam   = par.gam;  
  del   = par.del; 
  rho   = par.rho;
  lam   = par.lam;
  
  n = X(1);
  k = X(2);
  w = X(3);

% Steady state capital (k)
  x = del*k;

% Steady state rental price (R)
  R = 1/bet - 1 + del;

% Household's budget constraint (c)
  c = w*n + R*k - x;

% Feasibility (Y)
  Y = c + x;

% Adjusted world income
  W = Y*(alf^(1/(1-nu)) + (1-alf)^(1/(1-nu)));

% Intermediate good quality (q)
  q = ((gam - rho)*W*(nu/w)^(1/(1 - nu)))^((1 - nu)/(1 - (gam - rho + 1)*nu));

% Intermediate good price (p)
  p = (1/nu)*q^rho*w;

% Domestic intermediates demand (x)
  d = Y*(alf*q^(gam*nu)/p)^(1/(1 - nu));

% Foreign intermediates demand (m)
  m = Y*((1-alf)*q^(gam*nu)/p)^(1/(1 - nu));

% Intermediate goods production (y)
  y = d + m;

% Manufacturing labor demand (ly)
  ly = y*q^rho;

% Quality labor demand (lq)
  lq = q;

% Number of firms (I)
  I = (n*w+k*R)/(y*p);
  
% Marginal utilities
  if lam == 0
    Uc = c^(the*mu - 1)*(1 - n)^(the*(1 - mu));
  else
    Uc = (c - lam*n^mu)^(the-1);
  end
  
end        